@@ -34,6 +34,8 @@ module/mescc/M1.scm
 module/mescc/as.scm
 module/mescc/bytevectors.scm
 module/mescc/compile.scm
+module/mescc/armv4/as.scm
+module/mescc/armv4/info.scm
 module/mescc/i386/as.scm
 module/mescc/i386/info.scm
 module/mescc/x86_64/as.scm
@@ -60,6 +62,6 @@ for i in $SCM_FILES $SCRIPTS; do
     go=${i%%.scm}.go
     f=${srcdest}$i
     if test $f -nt $go; then
-        trace "GUILEC     $f" $GUILD compile -L ${srcdest}module -L ${srcdest}build-aux -L ${srcdest}scripts -o $go $f
+        trace "GUILEC     $f" $GUILD compile $GUILD_OPTIMIZE -L ${srcdest}module -L ${srcdest}build-aux -L ${srcdest}scripts -o $go $f
     fi
 done
