@@ -1,5 +1,5 @@
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2018,2019,2020,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 #
 # This file is part of GNU Mes.
 #
@@ -16,6 +16,25 @@
 # You should have received a copy of the GNU General Public License
 # along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
 
+case "$mes_cpu" in
+    arm)
+        stage0_arch=40
+        stage0_cpu=armv7l
+        ;;
+    x86_64)
+        stage0_arch=2
+        stage0_cpu=amd64
+        ;;
+    x86)
+        stage0_arch=1
+        stage0_cpu=x86
+        ;;
+    *)
+        stage0_arch=1
+        stage0_cpu=$mes_cpu
+        ;;
+esac
+
 AM_CPPFLAGS="
 -D HAVE_CONFIG_H=1
 -I ${srcdest}include
