@@ -40,26 +40,35 @@ rm -f "$o"
 CC=${CC-gcc}
 
 i=$(basename "$t" .c)
+
+if [ -z "${MES_CHECKING_BUILTIN_LIBS}" ]
+then
+    MES_CHECKING_BUILTIN_LIBS="`${CC} --print-libgcc-file-name`"
+fi
+
 if [ -z "${i/[012][0-9]-*/}" ]; then
-    LIBS=
+    LIBS="${MES_CHECKING_BUILTIN_LIBS} -l c-mini"
 elif [ -z "${i/[34][0-9]-*/}" ]; then
-    LIBS='-l c-mini'
+    LIBS="-l c-mini ${MES_CHECKING_BUILTIN_LIBS} -l c-mini"
 elif [ -z "${i/[78][0-9a-z]-*/}" ]; then
-    LIBS='-l c+tcc'
+    LIBS="-l c+tcc ${MES_CHECKING_BUILTIN_LIBS} -l c+tcc"
 elif [ -z "${i/9[0-9a-z]-*/}" ]; then
-    LIBS='-l c+gnu'
+    LIBS="-l c+gnu ${MES_CHECKING_BUILTIN_LIBS} -l c+gnu"
 else
-    LIBS='-l c'
+    # Make it possible to resolve raise(), required by libgcc.a, provided
+    # in libc.a.  The final command line has to have "-lc -lgcc -lc".
+    # See <https://www.openwall.com/lists/musl/2018/05/09/1>.
+    LIBS="-l c ${MES_CHECKING_BUILTIN_LIBS} -l c"
 fi
 
 if test $mes_kernel = gnu\
         && test -z "$LIBS"; then
-    LIBS="-l c-mini"
+    LIBS="-l c-mini -l mescc"
 fi
 
 if test $mes_libc = system; then
     crt1=
-    LIBS='-l mes'
+    LIBS='-l mes -l mescc'
 else
     crt1=crt1.o
 fi
@@ -68,7 +77,7 @@ $CC -g -c $AM_CPPFLAGS $CPPFLAGS $AM_CFLAGS $CFLAGS -o "$o".o "$t"
 $CC -g $AM_CFLAGS $CFLAGS $AM_LDFLAGS $LDFLAGS -L . -o "$o" $crt1 "$o".o $LIBS
 
 set +e
-timeout 10 "$o" -s --long file0 file1 > "$o".1 2> "$o".2
+timeout 20 "$o" -s --long file0 file1 > "$o".1 2> "$o".2
 r=$?
 set -e
 if [ -f "$b".exit ]; then
