@@ -67,7 +67,8 @@ extern void (*__call_at_exit) (void);
 #define __FILEDES_MAX 512
 
 #if !SYSTEM_LIBC
-void __assert_fail (char *s);
+void __assert_fail (char const *s, char const *file, unsigned line,
+                    char const *function);
 ssize_t __buffered_read (int filedes, void *buffer, size_t size);
 size_t __buffered_read_clear (int filedes);
 void _exit (int code);
