@@ -20,13 +20,13 @@
 #ifndef __MES_SYS_DIR_H
 #define __MES_SYS_DIR_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #undef __MES_SYS_DIR_H
 #include_next <sys/dir.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_SYS_DIR_H
