@@ -18,15 +18,36 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-char **environ = 0;
+#include <mes/lib-mini.h>
 // int main (int argc, char *argv[]);
 
 // gcc x86_64 calling convention:
 // rdi, rsi, rdx, rcx, r8, r9, <stack0>, <stack1>
 
+// *INDENT-OFF*
 void
 _start ()
 {
+  asm (
+       "mov    $0,%%eax\n\t"
+       "mov    %%eax,%0\n"
+       : "=r" (__stdin)
+       : //no inputs ""
+       );
+
+  asm (
+       "mov    $1,%%eax\n\t"
+       "mov    %%eax,%0\n"
+       : "=r" (__stdout)
+       : //no inputs ""
+       );
+
+  asm (
+       "mov    $2,%%eax\n\t"
+       "mov    %%eax,%0\n"
+       : "=r" (__stderr)
+       : //no inputs ""
+       );
   asm (
        "mov     %%rbp,%%rax\n\t"
        "add     $8,%%rax\n\t"
