@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -23,11 +23,13 @@
 #include <sys/types.h>
 #include <mes/lib.h>
 
+char *__getcwd_buf;
+
 char *
 getcwd (char *buffer, size_t size)
 {
   static char buf[PATH_MAX];
-  if (buffer)
-    return _getcwd (buffer, size);
-  return _getcwd (buf, PATH_MAX);
+  if (buffer == 0)
+    buffer = buf;
+  return _getcwd (buffer, size);
 }
