@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,28 +18,35 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <stdio.h>
+#include <unistd.h>
 
 size_t
-fwrite (void const *data, size_t size, size_t count, FILE *stream)
+fwrite (void const *data, size_t size, size_t count, FILE * stream)
 {
   if (__mes_debug () > 1)
     {
-      eputs ("fwrite "); eputs (itoa ((int)stream));
-      eputs ("  "); eputs (itoa (size)); eputs ("\n");
+      eputs ("fwrite ");
+      eputs (itoa ((int) (long) stream));
+      eputs ("  ");
+      eputs (itoa (size));
+      eputs ("\n");
     }
 
-  if (! size || !count)
+  if (!size || !count)
     return 0;
-  int bytes = write ((int)stream, data, size * count);
+  int filedes = (long) stream;
+  int bytes = write (filedes, data, size * count);
 
   if (__mes_debug () > 2)
     {
-      eputs (" => "); eputs (itoa (bytes)); eputs ("\n");
+      eputs (" => ");
+      eputs (itoa (bytes));
+      eputs ("\n");
     }
 
   if (bytes > 0)
-    return bytes/size;
+    return bytes / size;
   return 0;
 }
