@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -23,14 +23,18 @@
 int
 memcmp (void const *s1, void const *s2, size_t size)
 {
-  if (!size)
+  if (size == 0)
     return 0;
+
   char const *a = s1;
   char const *b = s2;
-  while (*a == *b && --size)
+
+  while (a[0] == b[0] && size > 1)
     {
-      a++;
-      b++;
+      size = size - 1;
+      a = a + 1;
+      b = b + 1;
     }
-  return *a - *b;
+
+  return a[0] - b[0];
 }
