@@ -355,8 +355,7 @@
     `((,(string-append "and____%" r1 ",%" r0)))))
 
 (define (i386:r0/r1 info signed?)
-  (let ((signed? #f)              ; nobody knows, -- all advice are belong to us?
-        (allocated (.allocated info))
+  (let ((allocated (.allocated info))
         (r0 (get-r0 info))
         (r1 (get-r1 info)))
     (if (not (member "edx" allocated))
@@ -381,8 +380,7 @@
           ("pop____%eax")))))
 
 (define (i386:r0%r1 info signed?)
-  (let ((signed? #f)              ; nobody knows, -- all advice are belong to us?
-        (allocated (.allocated info))
+  (let ((allocated (.allocated info))
         (r0 (get-r0 info))
         (r1 (get-r1 info)))
     (if (not (member "edx" allocated))
