@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -23,12 +23,12 @@
 #include <stdlib.h>
 
 int
-main (int argc, char *argv[])
+main (int argc, char **argv)
 {
-  __stdin = open ("scaffold/read.data", 0);
+  __stdin = open ("scaffold/read.data", 0, 0);
   int c = getchar ();
   if (c != 'm')
-    return 1;
+    return c;
   while (c != EOF)
     {
       putchar (c);
