@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -21,57 +21,53 @@
 #include "mes/lib.h"
 #include "mes/mes.h"
 
-#include <assert.h>
-
-SCM
-make_module_type ()             ///(internal))
+struct scm *
+make_module_type ()             /*:(internal)) */
 {
-  SCM record_type = cell_symbol_record_type;    // FIXME
-  SCM fields = cell_nil;
+  struct scm *fields = cell_nil;
   fields = cons (cstring_to_symbol ("globals"), fields);
   fields = cons (cstring_to_symbol ("locals"), fields);
   fields = cons (cstring_to_symbol ("name"), fields);
   fields = cons (fields, cell_nil);
   fields = cons (cell_symbol_module, fields);
-  return make_struct (record_type, fields, cell_unspecified);
+  return make_struct (cell_symbol_record_type, fields, cell_unspecified);
 }
 
-SCM
-make_initial_module (SCM a)     ///((internal))
+struct scm *
+make_initial_module (struct scm *a)     /*:((internal)) */
 {
-  SCM module_type = make_module_type ();
+  struct scm *module_type = make_module_type ();
   a = acons (cell_symbol_module, module_type, a);
 
-  SCM hashq_type = make_hashq_type ();
+  struct scm *hashq_type = make_hashq_type ();
   a = acons (cell_symbol_hashq_table, hashq_type, a);
 
-  SCM name = cons (cstring_to_symbol ("boot"), cell_nil);
-  SCM globals = make_hash_table_ (0);
-  SCM locals = cell_nil;
+  struct scm *name = cons (cstring_to_symbol ("boot"), cell_nil);
+  struct scm *globals = make_hash_table_ (0);
+  struct scm *locals = cell_nil;
 
-  SCM values = cell_nil;
+  struct scm *values = cell_nil;
   values = cons (globals, values);
   values = cons (locals, values);
   values = cons (name, values);
   values = cons (cell_symbol_module, values);
-  SCM module = make_struct (module_type, values, cstring_to_symbol ("module-printer"));
-  r0 = cell_nil;
-  r0 = cons (CADR (a), r0);
-  r0 = cons (CAR (a), r0);
-  m0 = module;
-  while (TYPE (a) == TPAIR)
+  struct scm *module = make_struct (module_type, values, cstring_to_symbol ("module-printer"));
+  R0 = cell_nil;
+  R0 = cons (a->cdr->car, R0);
+  R0 = cons (a->car, R0);
+  M0 = module;
+  while (a->type == TPAIR)
     {
-      module_define_x (module, CAAR (a), CDAR (a));
-      a = CDR (a);
+      module_define_x (module, a->car->car, a->car->cdr);
+      a = a->cdr;
     }
 
   return module;
 }
 
-SCM
-module_printer (SCM module)
+struct scm *
+module_printer (struct scm *module)
 {
-  //module = m0;
   fdputs ("#<", __stdout);
   display_ (struct_ref_ (module, 2));
   fdputc (' ', __stdout);
@@ -81,40 +77,40 @@ module_printer (SCM module)
   fdputs ("locals: ", __stdout);
   display_ (struct_ref_ (module, 4));
   fdputc (' ', __stdout);
-  SCM table = struct_ref_ (module, 5);
+  struct scm *table = struct_ref_ (module, 5);
   fdputs ("globals:\n  ", __stdout);
   display_ (table);
   fdputc ('>', __stdout);
 }
 
-SCM
-module_variable (SCM module, SCM name)
+struct scm *
+module_variable (struct scm *module, struct scm *name)
 {
-  //SCM locals = struct_ref_ (module, 3);
-  SCM locals = module;
-  SCM x = assq (name, locals);
+  /*struct scm *locals = struct_ref_ (module, 3);*/
+  struct scm *locals = module;
+  struct scm *x = assq (name, locals);
   if (x == cell_f)
     {
-      module = m0;
-      SCM globals = struct_ref_ (module, 5);
+      module = M0;
+      struct scm *globals = struct_ref_ (module, 5);
       x = hashq_get_handle (globals, name, cell_f);
     }
   return x;
 }
 
-SCM
-module_ref (SCM module, SCM name)
+struct scm *
+module_ref (struct scm *module, struct scm *name)
 {
-  SCM x = module_variable (module, name);
+  struct scm *x = module_variable (module, name);
   if (x == cell_f)
     return cell_undefined;
-  return CDR (x);
+  return x->cdr;
 }
 
-SCM
-module_define_x (SCM module, SCM name, SCM value)
+struct scm *
+module_define_x (struct scm *module, struct scm *name, struct scm *value)
 {
-  module = m0;
-  SCM globals = struct_ref_ (module, 5);
+  module = M0;
+  struct scm *globals = struct_ref_ (module, 5);
   return hashq_set_x (globals, name, value);
 }
